@@ -830,6 +830,7 @@ impl<S, C> Api<C> for Client<S, C> where
         param_date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
         param_place_of_birth: Option<String>,
         param_polity_name: Option<String>,
+        param_specialism: Option<String>,
         param_sorts: Option<&Vec<models::StudentSortCriteria>>,
         param_offset: Option<i32>,
         param_count: Option<i32>,
@@ -872,6 +873,10 @@ impl<S, C> Api<C> for Client<S, C> where
                 query_string.append_pair("polityName",
                     &param_polity_name.to_string());
             }
+            if let Some(param_specialism) = param_specialism {
+                query_string.append_pair("specialism",
+                    &param_specialism.to_string());
+            }
             if let Some(param_sorts) = param_sorts {
                 query_string.append_pair("sorts",
                     &param_sorts.iter().map(ToString::to_string).collect::<Vec<String>>().join(","));
