@@ -10,7 +10,7 @@ use serde::{Serialize, Deserialize};
 type ServiceError = Box<dyn Error + Send + Sync + 'static>;
 
 pub const BASE_PATH: &'static str = "";
-pub const API_VERSION: &'static str = "0.2.1";
+pub const API_VERSION: &'static str = "0.2.2";
 
 #[derive(Debug, PartialEq, Serialize, Deserialize)]
 #[must_use]
@@ -123,6 +123,7 @@ pub trait Api<C: Send + Sync> {
         date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
         place_of_birth: Option<String>,
         polity_name: Option<String>,
+        specialism: Option<String>,
         sorts: Option<&Vec<models::StudentSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
@@ -173,6 +174,7 @@ pub trait ApiNoContext<C: Send + Sync> {
         date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
         place_of_birth: Option<String>,
         polity_name: Option<String>,
+        specialism: Option<String>,
         sorts: Option<&Vec<models::StudentSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
@@ -254,13 +256,14 @@ impl<T: Api<C> + Send + Sync, C: Clone + Send + Sync> ApiNoContext<C> for Contex
         date_of_birth: Option<chrono::DateTime::<chrono::Utc>>,
         place_of_birth: Option<String>,
         polity_name: Option<String>,
+        specialism: Option<String>,
         sorts: Option<&Vec<models::StudentSortCriteria>>,
         offset: Option<i32>,
         count: Option<i32>,
         ) -> Result<GetStudentsResponse, ApiError>
     {
         let context = self.context().clone();
-        self.api().get_students(name, email, phone, undergraduate_school, date_of_birth, place_of_birth, polity_name, sorts, offset, count, &context).await
+        self.api().get_students(name, email, phone, undergraduate_school, date_of_birth, place_of_birth, polity_name, specialism, sorts, offset, count, &context).await
     }
 
 }
