@@ -661,6 +661,23 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                     },
                     None => None,
                 };
+                let param_specialism = query_params.iter().filter(|e| e.0 == "specialism").map(|e| e.1.to_owned())
+                    .nth(0);
+                let param_specialism = match param_specialism {
+                    Some(param_specialism) => {
+                        let param_specialism =
+                            <String as std::str::FromStr>::from_str
+                                (&param_specialism);
+                        match param_specialism {
+                            Ok(param_specialism) => Some(param_specialism),
+                            Err(e) => return Ok(Response::builder()
+                                .status(StatusCode::BAD_REQUEST)
+                                .body(Body::from(format!("Couldn't parse query parameter specialism - doesn't match schema: {}", e)))
+                                .expect("Unable to create Bad Request response for invalid query parameter specialism")),
+                        }
+                    },
+                    None => None,
+                };
                 let param_sorts = query_params.iter().filter(|e| e.0 == "sorts").map(|e| e.1.to_owned())
                     .filter_map(|param_sorts| param_sorts.parse().ok())
                     .collect::<Vec<_>>();
@@ -712,6 +729,7 @@ impl<T, C> hyper::service::Service<(Request<Body>, C)> for Service<T, C> where
                                             param_date_of_birth,
                                             param_place_of_birth,
                                             param_polity_name,
+                                            param_specialism,
                                             param_sorts.as_ref(),
                                             param_offset,
                                             param_count,
